<?php
$lang['0_product'] = 'Product ';
$lang['1_service'] = 'Service ';
$lang['2_discount'] = 'Korting';
$lang['3_shipping'] = 'Transport';
$lang['4_tax'] = 'BTW';
$lang['addedit_billingform_template'] = 'Toevoegen/wijzigen Factuur Formulier sjabloon';
$lang['addedit_completion_template'] = 'Toevoegen/wijzigen afrondingssjabloon';
$lang['addedit_confirmorder_template'] = 'Toevoegen/wijzigen Bevestig Order Sjabloon';
$lang['addedit_gateway_complete_template'] = 'Toevoegen/wijzigen Gateway Complete Sjabloon';
$lang['addedit_invoice_template'] = 'Toevoegen/wijzigen offerte sjabloon';
$lang['addedit_paymentform_template'] = 'Toevoegen/wijzigen Betalingsformulier Sjabloon';
$lang['address1'] = 'Adresregel 1';
$lang['address2'] = 'Adresregel 2';
$lang['address_handling'] = 'Adres afhandeling';
$lang['add_msg_template'] = 'Voeg nieuw berichtensjabloon toe';
$lang['admin_email_addresses'] = 'Een komma gescheiden lijst van admin e-mail adressen te gebruiken wanneer een order is toegevoegd';
$lang['admin_email_template'] = 'Beheerder E-mail Sjabloon';
$lang['amount'] = 'Bedrag';
$lang['amt_due'] = 'Te betalen';
$lang['any'] = 'Ieder';
$lang['ask_delete'] = 'Weet je zeker dat je dit artikel wilt verwijderen?';
$lang['ask_delete_order'] = 'Weet u zeker dat u deze order wilt verwijderen?  Het is normaal gesproken niet gewoon om orders te verwijderen...';
$lang['ask_delete_payment'] = 'Weet u zeker dat u deze gegevens van de betaling permanent wilt verwijderen?';
$lang['ask_edit_billing'] = 'Weet u zeker dat u de facturering gegevens wilt wijzigen van de bovenstaande order?';
$lang['ask_manual_payment'] = 'Weet u zeker dat u een handmatige betaling voor dit bedrag met een creditcard wilt uitvoeren?';
$lang['ask_saveprefs'] = 'Weet u zeker dat u de instellingen voor deze module wilt aanpassen?\nWees voorzichtig, verkeerde wijzigingen kunnen een werkende website doen falen.';
$lang['ask_setorderstatus'] = 'Er is een mogelijke order status wijziging gedetecteerd, wilt u de status wijzigen naar: ';
$lang['back'] = 'Terug';
$lang['back_to_orders'] = 'Terug naar Orders';
$lang['backorder'] = 'Nabestelling';
$lang['balancedue'] = 'Balans (gedeeltelijk betaald)';
$lang['bill_to'] = 'Factuur naar';
$lang['billing'] = 'Facturering';
$lang['billing_address'] = 'Factuuradres';
$lang['billing_form_templates'] = 'Factuur formuliersjablonen';
$lang['billing_info'] = 'Factuurinformatie';
$lang['body'] = 'Bericht';
$lang['cancel'] = 'Annuleer';
$lang['cancelled'] = 'Geannuleerd';
$lang['captcha_title'] = 'Captcha Tekst';
$lang['cart_module'] = 'Cart Module ';
$lang['cart_settings'] = 'Cart instellingen';
$lang['cash'] = 'Contant';
$lang['cc_AMEX'] = 'American Express ';
$lang['cc_Discover'] = 'Discover ';
$lang['cc_MasterCard'] = 'Mastercard ';
$lang['cc_Visa'] = 'Visa ';
$lang['city'] = 'Stad';
$lang['company'] = 'Bedrijf';
$lang['completed'] = 'Gereed';
$lang['completion_templates'] = 'Afrondingssjablonen';
$lang['confirmed'] = 'Bevestigd';
$lang['confirm_order'] = 'Bevestig order';
$lang['confirmation_form_templates'] = 'Bevestigingssjablonen';
$lang['confirmation_num'] = 'Bevestigingsnummer';
$lang['cookie'] = 'Bewaar het adres in een cookie.';
$lang['country'] = 'Land';
$lang['coupon_code'] = 'Kortingscode';
$lang['created'] = 'Gemaakt';
$lang['created_by'] = 'Gemaakt door';
$lang['create_invoice'] = 'Maak een factuur voor deze order';
$lang['create_invoice_for'] = 'Maak factuur voor order %s';
$lang['creditcard'] = 'Credit Card ';
$lang['creditcard_expiry'] = 'Credit Card vervaldatum';
$lang['creditcard_number'] = 'Credit Card Nummer';
$lang['creditcard_type'] = 'Credit Card type ';
$lang['creditcard_verifycode'] = 'Verificatiecode';
$lang['customer_name'] = 'Klantnaam';
$lang['date'] = 'Datum';
$lang['date_range'] = 'Datum ';
$lang['dateopt_exactdates'] = 'Precieze data';
$lang['dateopt_7days'] = 'Laatste 7 dagen';
$lang['dateopt_14days'] = 'Laatste 14 dagen';
$lang['dateopt_30days'] = 'Laatste 30 dagen';
$lang['dateopt_3months'] = 'Laatste 3 maanden';
$lang['dateopt_6months'] = 'Laatste 6 maanden';
$lang['dateopt_1year'] = 'Laatste jaar';
$lang['default_templates'] = 'Standaard sjablonen';
$lang['delete'] = 'Verwijder';
$lang['delivered'] = 'Afgeleverd';
$lang['description'] = 'Omschrijving';
$lang['desc_order_by'] = 'Besteld door {$billing->get_firstname()} {$billing->get_lastname()}';
$lang['destinations'] = 'Bestemmingen';
$lang['details'] = 'Details ';
$lang['dflt_billingform_template'] = 'Standaard factuursjabloon';
$lang['dflt_confirmorder_template'] = 'Standaard orderbevestigings sjabloon';
$lang['dflt_completion_template'] = 'Standaard volledigheids sjabloon';
$lang['dflt_gateway_complete_template'] = 'Standaard &quot;Gateway Transaction Complete&quot; Sjabloon';
$lang['dflt_invoice_message'] = 'Bedankt voor het kopen bij {sitename}.';
$lang['dflt_invoice_template'] = 'Standaard factuursjabloon';
$lang['dflt_paymentform_template'] = 'Standaard betalingssjabloon';
$lang['discount'] = 'Korting';
$lang['edit'] = 'Wijzig';
$lang['edit_billing_info'] = 'Wijzig factuurinformatie';
$lang['edit_report_template'] = 'Wijzigen van het sjabloon voor het rapport: %s';
$lang['end_date'] = 'Eind datum';
$lang['email'] = 'E-mail ';
$lang['email_address'] = 'E-mailadres';
$lang['email_invoice'] = 'E-mail deze factuur naar de klant en geautoriseerde admins';
$lang['email_sent_to'] = 'E-mail verstuurd naar';
$lang['email_subject'] = 'E-mail onderwerp';
$lang['error_badcaptcha'] = 'De Captcha tekst is verkeerd overgenomen';
$lang['error_creditcard_expired'] = 'Deze Credit Card is verlopen';
$lang['error_encryption_problem'] = 'Een probleem is opgetreden bij het encrypten/decrypten van data';
$lang['error_gateway_invalid_data'] = 'Kan de data niet valideren met de betalingsgateway module';
$lang['error_insufficientparams'] = 'Een verplichte parameter mist';
$lang['error_invalid_address'] = 'Het ingevoerde adres is niet correct (Controleer of u alle benodigde velden heeft ingevuld)';
$lang['error_invalidfield'] = 'Het volgende veld is ongeldig: %s';
$lang['error_invalidgateway'] = 'De geselecteerde gateway module is niet bruikbaar voor dit doel';
$lang['error_missingshippinginfo'] = 'Onvoldoende transport informatie opgegeven';
$lang['error_namexists'] = 'Een artikel met deze naam bestaat reeds';
$lang['error_nocartmodule'] = 'Cart module niet gevonden';
$lang['error_noemailaddress'] = 'Geen E-mailadres is verbonden met deze userid';
$lang['error_nofeumodule'] = 'FrontEndUsers module niet gevonden';
$lang['error_nopaymentgateway'] = 'Geen &#039;payment gateway&#039;  opgegeven';
$lang['error_noproductsmodule'] = 'Kan de Products module niet vinden';
$lang['error_norequiredgroup'] = 'Stel een verplichte ledengroep in onder de instellingen tab';
$lang['error_notloggedin'] = 'Gebruiker is niet ingelogd <em>&oacute;f is geen lid van een vereiste gebruikersgroep</em>';
$lang['error_orderinvalid'] = 'Er is een probleem met deze order (de informatie is incorrect)';
$lang['error_ordernotfound'] = 'Gevraagde order niet gevonden';
$lang['error_orderprocessing'] = 'Er is een fout opgetreden bij het verwerken van deze bestelling (soft fail)';
$lang['error_paymentnotfound'] = 'De gespecificeerde betaling kan niet worden gevonden';
$lang['error_possible_hack'] = 'Een mogelijke hack gedetecteerd: uw uid (%s) komt niet overeen met de uid (%s) gevonden voor de order %s.  Neem contact op met uw systeembeheerder.';
$lang['error_requiressl'] = 'De voor gebruik op deze site geselecteerde gateway vereist een beveiligde verbinding, welke nog niet tot stand is gebracht';
$lang['error_retrieve_data'] = 'Er is een probleem opgetreden bij het verkrijgen van informatie vanuit de database';
$lang['error_save'] = 'Fout tijdens opslaan van data item: %s';
$lang['error_security_key'] = 'De encryptie-sleutel voor deze transactie kon niet worden opgehaald';
$lang['error_paymentgateway_incompatible'] = 'De geselecteerde &quot;payment gateway&quot; is niet compatibel met deze order verwerkings module. Neem contact op met de site beheerder';
$lang['error_permissiondenied'] = 'Toegang geweigerd';
$lang['error_unknownstatus'] = 'Een onbekende status van de betalingsgateway gekregen';
$lang['error_usernotingroup'] = 'Ingelogde gebruiker is geen lid van de benodigde groep';
$lang['fax'] = 'Fax ';
$lang['filter'] = 'Filter ';
$lang['first_name'] = 'Voornaam';
$lang['firstpage'] = '<< ';
$lang['friendlyname'] = 'Order beheerder';
$lang['from'] = 'Van';
$lang['gateway'] = 'Gateway ';
$lang['gateway_module'] = 'Payment Gateway Module ';
$lang['gateway_complete_templates'] = 'Gateway volledigheidssjabloon';
$lang['gateway_failure_message'] = 'Uw transactie is niet afgerond.  Of de actie is be&euml;indigd of er is een storing opgetreden.  Controleert u uw betalingsgegevens en probeer het opnieuw. Uw winkelwagen is geleegd voor uw veiligheid. Bedankt voor uw tijd.';
$lang['general_settings'] = 'Algemene instellingen';
$lang['get_address_from_feu'] = 'Gebruik klantprofiel';
$lang['help_param_nocaptcha'] = 'Inschakelen van deze parameter, schakelt Captcha uit';
$lang['help_param_template'] = 'Specificeer een niet standaard sjabloon voor deze standaard actie';
$lang['hold'] = 'Houd vast';
$lang['html'] = 'HTML ';
$lang['html_email'] = 'Stuur e-mail in HTML-formaat';
$lang['id'] = 'Id ';
$lang['incomplete'] = 'Niet compleet (gedeeltelijk verzonden)';
$lang['info_admin_invoice_template'] = 'Selecteer een sjabloon die moet worden gebruikt als er een printbare factuur popup wordt getoond wanneer een order word bewerkt.';
$lang['info_adminemail_template'] = 'Dit sjabloon bevat the layout en inhoud van de e-mail die wordt verstuurd naar de geautoriseerde administrator wanneer er een order is geplaatst';
$lang['info_allow_anon_checkout'] = 'Als dit is uitgeschakeld, dan zijn gebruikers vereist om een geldige FEU-login te hebben om het bestelproces te kunnen afronden.';
$lang['info_allow_creditcard_entry'] = '<strong>Opmerking:</strong> Deze informatie is opgeslagen in de database.<br/>Ondanks dat er encryptie word gebruikt om de persoonsgebonden data op te slaan,<br/>is het aan te bevelen deze optie niet te gebruiken.<br/>Gebruik hiervoor een betalingsmodule (payment gateway module).';
$lang['info_billingpage'] = '<strong>Opmerking:</strong> De instelling en andere die erop lijken worden gebruikt om de administrator om verschillende CMSMS pagina&#039;s te gebruiken voor de verschillende formulieren. Als er geen is geselecteerd, dan zal de huidige pagina worden gebruikt.';
$lang['info_ccprocessing_module'] = 'Deze module wordt gebruikt voor het handmatig verwerken van creditcard gegevens';
$lang['info_coupon_code'] = 'Voer een code in voor een mogelijke korting';
$lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
$lang['info_edit_report_template'] = 'Dit sjabloon bepaalt de stijl en de lay-out voor een individueel rapport';
$lang['info_encryption_key'] = 'Deze sleutel is willekeurig gegenereerd bij de module installatie. Wees voorzichtig bij het wijzigen van deze waarde als er al orders in het systeem staan.';
$lang['info_forcessl'] = '<strong>Opmerking: Aanbevolen</strong>. Als u klanten toestaat om creditcard gegevens in te voeren, dan is het aan te raden om deze functie in te schakelen en u er van te verzekeren dat uw site beschikt over een goed geconfigureerde SSL-verbinding zodat de overdracht van de creditcard informatie beveiligd worden verzonden.';
$lang['info_gateway_description'] = 'Deze informatie wordt verzonden naar de betaalgateway voor iedere transactie en kan worden gebruikt voor bijvoorbeeld de naam die wordt weergegeven bij de afhandeling van de betaling met een creditcard.  Dit is een smarty-sjabloon, het is dus mogelijk om de weergave aan te passen.';
$lang['info_incomplete_timeout'] = 'Voorgestelde orders met een bepaalde inactieve tijd (in minuten) kunnen na die tijd automatisch de status &#039;incompleet&#039; krijgen. Als u de waarde instelt op 0, dan is deze functie uitgeschakeld.';
$lang['info_invoicepage'] = '<strong>Opmerking:</strong> Deze pagina wordt ook gebruikt als succes- en foutpagina voor de betalingsgateway';
$lang['inform_no_cc_processing'] = 'Weet u zeker dat u bestaande betaalinformatie wilt aanpassen?\nEr zal geen nieuwe creditcard transactie plaatsvinden.';
$lang['info_order_notes'] = 'Geef speciale notities op voor deze order';
$lang['info_require_membergroup'] = 'Deze instellingen zijn alleen van toepassing als het NIET is toegestaan voor anonieme gebruikers om een bestelling te plaatsen';
$lang['info_skip_invoice_page'] = 'Indien u toestaat gebruikers betaalinformatie te op te geven<br/>moeten zij dan worden doorverwezen naar de factuurpagina,<br/>of direct naar de pagina met de voltooiing van de transactie?';
$lang['info_store_creditcard_data'] = '<strong>Opmerking: <span style=&quot;color: red;&quot;>Niet aanbevolen</span></strong> Deze informatie wordt opgeslagen in de database. Ondanks dat er versleuteling wordt toegepast op de informatie, is dit niet volledig veilig. Het is aanbevolen deze optie niet te gebruiken. U kunt beter op zoek gaan naar een betere betaalgateway module.';
$lang['info_useremail_template'] = 'Dit sjabloon bevat the layout en inhoud van de e-mail die wordt verstuurd naar de gebruiker wanneer een order is geplaatst';
$lang['info_validcountries'] = 'Geef een lijst om met landcodes en landnamen (een per regel) voor de landen die moeten worden weergegeven in de adressenlijst. Bijvoorbeeld: NL=Nederland. Als er geen waarde is opgegeven, dan zal de standaard landenlijst worden gebruikt.';
$lang['info_validstates'] = 'Geef een lijst op met codes en namen van staten of provincies (een per regel). Deze zullen worden weergegeven in de adressen lijst. Bijvoorbeeld: GL=Gelderland. Als er geen waarde is opgegeven, dan zal de standaard lijst worden gebruikt.';
$lang['info_use_integer'] = 'Gebruik alleen integere waarden';
$lang['interval_oneday'] = 'E&eacute;n dag';
$lang['interval_onemonth'] = 'E&eacute;n maand';
$lang['interval_onequarter'] = 'E&eacute;n kwartaal';
$lang['interval_oneweek'] = 'E&eacute;n week';
$lang['interval_oneyear'] = 'E&eacute;n jaar';
$lang['interval_twoweeks'] = 'Twee weken';
$lang['invoice'] = 'Factuur';
$lang['invoiced'] = 'Gefactureerd';
$lang['invoice_settings'] = 'Factuur instellingen';
$lang['invoice_templates'] = 'Factuursjablonen';
$lang['items'] = 'Artikelen';
$lang['last_name'] = 'Achternaam';
$lang['last_modified'] = 'Laatste wijziging';
$lang['lastpage'] = '>> ';
$lang['lbl_back'] = 'Terug';
$lang['lbl_preferences'] = 'Instellingen';
$lang['lbl_templates'] = 'Sjablonen';
$lang['legend_dates'] = 'Selecteer data';
$lang['legend_reports'] = 'Rapporten';
$lang['message'] = 'Bericht';
$lang['message_templates'] = 'Berichtsjablonen';
$lang['method'] = 'Methode';
$lang['moddescription'] = 'Een eenvoudige orderverwerkings-module';
$lang['modified'] = 'Aangepast';
$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
$lang['msg_order_cancelled'] = 'Order %s geannuleerd of niet geaccepteerd';
$lang['msg_order_error'] = 'Fout opgetreden bij order %s';
$lang['msg_order_payment'] = 'Betaling ontvangen voor order %s.';
$lang['msg_order_pending'] = 'Order status gewijzigd naar &quot;In behandeling&quot; voor %s';
$lang['msg_payment_cancelled'] = 'Betaling %s is geannuleerd voor de order %s';
$lang['msg_payment_declined'] = 'Betaling %s is geweigerd voor de order %s';
$lang['msg_payment_error'] = 'Er is een fout opgetreden voor de betaling %s van de order %s';
$lang['msg_payment_received'] = 'Betaling %s (%s) is ontvangen voor de order %s';
$lang['msg_payment_removed'] = 'Betaling van de order verwijderd';
$lang['msg_payment_setbackwards'] = 'Geprobeerd om de status van de order %s te wijzigen van BETAALD naar WACHTEND';
$lang['name'] = 'Naam';
$lang['net'] = 'Netto';
$lang['net_price'] = 'Netto Prijs';
$lang['new_order_submitted'] = 'Een nieuwe order is verwerkt';
$lang['next'] = 'Volgende';
$lang['nextpage'] = '> ';
$lang['no'] = 'Nee';
$lang['no_items_in_cart'] = 'Geen artikelen in uw winkelwagen. Voeg een aantal toe alvorens verder te gaan';
$lang['no_report_data'] = 'Geen vergelijkbare data gevonden';
$lang['none'] = 'Geen';
$lang['notcancelledshipped'] = 'Alle behalve geannuleerde of verzonden';
$lang['notes'] = 'Notities';
$lang['notshipped'] = 'Niet verzonden';
$lang['num'] = 'Nee.';
$lang['online'] = 'online';
$lang['order'] = 'Order ';
$lang['orders'] = 'Orders ';
$lang['order_confirm_form_templates'] = 'Bevestig Ordersjablonen';
$lang['order_details'] = 'Orderdetails';
$lang['order_notes'] = 'Ordernotities';
$lang['order_number'] = 'Order Nr.';
$lang['order_processing'] = 'Order Bewerking';
$lang['order_statistics'] = 'Orderstatistieken';
$lang['order_summary'] = 'Ordersamenvatting';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Korting';
$lang['paid'] = 'Betaald';
$lang['payment_amount'] = 'Hoogte factuurbedrag';
$lang['payment_approved'] = 'Goedgekeurd';
$lang['payment_cancelled'] = 'Geannuleerd';
$lang['payment_date'] = 'Betalingsdatum';
$lang['payment_declined'] = 'Afgewezen';
$lang['payment_error'] = 'Fout';
$lang['payment_form_templates'] = 'Betalingsformulier sjablonen';
$lang['payment_gateway_settings'] = 'Betalings Gateway Instellingen';
$lang['payment_history'] = 'Betalingsgeschiedenis';
$lang['payment_info'] = 'Betalingsinformatie';
$lang['payment_method'] = 'Betalingsmethode';
$lang['payment_notprocessed'] = 'Niet verwerkt';
$lang['payment_options'] = 'Betalingsopties';
$lang['payment_other'] = 'Anders';
$lang['payment_pending'] = 'Afwachtende';
$lang['payment_status'] = 'Betalingsstatus';
$lang['pending'] = 'In behandeling';
$lang['phone'] = 'Telefoon';
$lang['popup_new_window'] = 'Popup factuur in een nieuw scherm';
$lang['postinstall'] = 'De Orders module is geinstalleerd';
$lang['postuninstall'] = 'De Orders module en alle geassocieerde data is verwijderd';
$lang['post_order_msg'] = 'Voor Order Bericht';
$lang['postal'] = 'Postcode';
$lang['preferences'] = 'Voorkeuren';
$lang['prevpage'] = '< ';
$lang['price'] = 'Prijs';
$lang['print_invoice'] = 'Druk factuur af';
$lang['procede_manual_checkout'] = 'Doorgaan met de handmatige controle';
$lang['process_manual_payment'] = 'Verwerk handmatige betaling';
$lang['process_new_transaction'] = 'Credit Card Transactie verwerking via Gateway';
$lang['process_order'] = 'Verwerk Order';
$lang['product_id'] = 'Product ID ';
$lang['promotions_module'] = 'Promotions Module ';
$lang['promotions_settings'] = 'Promotions Instellingen';
$lang['prompt_address_property_map'] = 'Adres op FEU Property Map';
$lang['prompt_address_retrieval'] = 'Adres opzoek methode';
$lang['prompt_admin_invoice_template'] = 'Te printen factuur sjabloon';
$lang['prompt_allow_anon_checkout'] = 'Sta anonieme gebruikers toe om te bestellen';
$lang['prompt_allow_creditcard_entry'] = 'Sta klanten toe om hun Credit Card gegevens in te voeren';
$lang['prompt_billingpage'] = 'Pagina waar de factuur wordt getoond.  Dit is meestal de pagina met de <code>{Orders}</code> tag.';
$lang['prompt_ccprocessing_module'] = 'Credit Card Verwerking Gateway';
$lang['prompt_confirmpage'] = 'Te gebruiken pagina voor het tonen van het bevestigingsformulier';
$lang['prompt_datastore_timeout'] = 'Verloopperiode voor tijdelijke transactie informatie';
$lang['prompt_date_search_type'] = 'Filter Records die zijn';
$lang['prompt_dflt_country'] = 'Standaard land';
$lang['prompt_dflt_state'] = 'Standaard staat';
$lang['prompt_email'] = 'E-mail adres';
$lang['prompt_encryption_key'] = 'Encryptiesleutel';
$lang['prompt_forcessl'] = 'Verwijs de pagina naar HTTPS voor de invoer van betalingsgegevens';
$lang['prompt_gateway_description'] = 'Omschrijving om naar de betalingsgateway te sturen';
$lang['prompt_incomplete_timeout'] = 'Zet orders automatisch op incompleet <em>(indien voorgesteld)</em> na N minuten';
$lang['prompt_invoice_message'] = 'Bericht dat boven alle facturen getoond moet worden';
$lang['prompt_invoicepage'] = 'Te gebruiken pagina voor het tonen van de factuur';
$lang['prompt_of'] = 'Van';
$lang['prompt_ordernum_prefix'] = 'Ordernummer Prefix';
$lang['prompt_page'] = 'Pagina';
$lang['prompt_pagelimit'] = 'Aantal Orders per pagina';
$lang['prompt_paymentpage'] = 'Te gebruiken pagina voor het betalingsformulier';
$lang['prompt_permit_deletion'] = 'Sta het verwijderen van orders toe';
$lang['prompt_requirepostal'] = 'Postcode is een vereist veld op het betalingsformulier';
$lang['prompt_requirestate'] = 'Provincie is een vereist veld op het betalingsformulier';
$lang['prompt_skip_invoice_page'] = 'Sla factuurpagina over';
$lang['prompt_store_creditcard_data'] = 'Credit Card Informatie Opslaan';
$lang['prompt_template'] = 'Berichtsjabloon';
$lang['prompt_username'] = 'Gebruikersnaam';
$lang['prompt_validcountries'] = 'Geldige landen:';
$lang['prompt_validstates'] = 'Geldige provincies:';
$lang['proposed'] = 'Voorgesteld';
$lang['quantity'] = 'Hoeveelheid';
$lang['really_uninstall'] = 'Weet u zeker dat u dit wilt doen? Alle data geassocieerd met deze module zal worden verwijderd.';
$lang['records_matching_query'] = 'Aantal records die gelijk zijn aan uw opdracht';
$lang['regex'] = 'Reguliere Expressie';
$lang['remember_last_address_used'] = 'Gebruik het adres van de laatste order';
$lang['report'] = 'Rapport';
$lang['reports'] = 'Rapporten';
$lang['report_recent_payments'] = 'Recente betalingen';
$lang['report_shipping_costs'] = 'Transportkosten';
$lang['report_subscr_picklist'] = 'Abonnementen keuzelijst';
$lang['report_templates'] = 'Rapport Sjablonen';
$lang['return'] = 'Terug';
$lang['require_group_membership'] = 'Verplicht alle gebruikers die een order plaatsen lid te zijn van een FEU groep';
$lang['security_settings'] = 'Veiligheids instellingen';
$lang['select_action'] = 'Selecteer Actie';
$lang['select_one'] = 'Selecteer &eacute;&eacute;n';
$lang['select_invoice_template'] = 'Selecteer factuursjabloon';
$lang['send'] = 'Verzend';
$lang['send_message'] = 'Verstuur bericht naar deze klant';
$lang['sent'] = 'Verzonden';
$lang['ship_to'] = 'Verzend naar';
$lang['shipped'] = 'Verzonden';
$lang['shipping'] = 'Verzending';
$lang['shipping_address'] = 'Verzendadres';
$lang['shipping_costs'] = 'Transportkosten';
$lang['shipping_info'] = 'Verzendinformatie';
$lang['shipping_info_for'] = 'Verzendadres voor';
$lang['shipping_info_if_different'] = 'Verzendinformatie <em>(Indien afwijkend van factuurinformatie)</em>';
$lang['shipping_message'] = 'Bericht in relatie tot de bestemming';
$lang['shipping_module'] = 'Shipping Module ';
$lang['shipping_settings'] = 'Shipping instellingen';
$lang['shipping_total'] = 'Verzendtotaal';
$lang['sku'] = 'SKU ';
$lang['source'] = 'Bron';
$lang['special_instructions'] = 'Speciale instructies';
$lang['start_date'] = 'Start Datum';
$lang['state/province'] = 'Provincie';
$lang['status'] = 'Status ';
$lang['subscription'] = 'Abonnementen';
$lang['subject'] = 'Onderwerp';
$lang['submit'] = 'Verzend';
$lang['submitted'] = 'Verzonden';
$lang['submit_payment_info'] = 'Verzend betaalinformatie';
$lang['subscribed'] = 'Geabonneerd';
$lang['subtotal'] = 'Subtotaal';
$lang['tax'] = 'BTW';
$lang['tax_module'] = 'BTW Module';
$lang['tax_settings'] = 'BTW Instellingen';
$lang['template'] = 'Sjabloon';
$lang['template_name'] = 'Sjabloonnaam';
$lang['thank_you_for_order'] = 'Bedankt voor uw aankoop op {sitename}';
$lang['timeout'] = 'Verlopen';
$lang['title_adminemail_template'] = 'Beheerder E-mail Sjabloon';
$lang['title_first_page'] = 'Ga naar de eerste pagina';
$lang['title_last_page'] = 'Ga naar de laatste pagina';
$lang['title_manage_order'] = 'Beheer Order';
$lang['title_manual_process'] = 'Handmatige transactie-verwerking';
$lang['title_next_page'] = 'Ga naar de volgende pagina';
$lang['title_prev_page'] = 'Ga naar de vorige pagina';
$lang['title_useremail_template'] = 'Gebruikers E-mail Sjabloon';
$lang['to'] = 'Tot';
$lang['total'] = 'Totaal';
$lang['tracking_num'] = 'Trackingnummer';
$lang['transaction_id'] = 'Transactie Id';
$lang['transaction_successful'] = 'Betaling is geslaagd';
$lang['type'] = 'Type ';
$lang['update_status'] = 'Update Status ';
$lang['unit_price'] = 'Stuksprijs';
$lang['unit_weight'] = 'Stuksgewicht';
$lang['unknown'] = 'Onbekend';
$lang['unlimited'] = 'Ongelimiteerd';
$lang['username'] = 'Gebruikersnaam';
$lang['user_email_template'] = 'Gebruikers E-mail Sjabloon';
$lang['view'] = 'Bekijk';
$lang['view_message'] = 'Bekijk bericht';
$lang['view_messages'] = 'Bekijk berichten behorende bij deze order';
$lang['warning_https'] = '<strong>Waarschuwing!</strong> U gebruikt geen veilige (https) verbinding. Het is niet aanbevolen om verder te gaan met deze actie zonder een beveiligde verbinding.';
$lang['warning_manual_process'] = '<strong>Waarschuwing!</strong> Dit scherm staat u toe om handmatige uitvoer van credit card transacties te doen via een online gateway. Wees voorzichtig!';
$lang['warning_orderstatus_paid'] = '<strong>Waarschuwing!</strong> - Deze order is al betaald. U moet niet verder gaan met de betalingsactie van de order';
$lang['warning_orderstatus_cancelled'] = '<strong>Waarschuwing!</strong> - De order is geannuleerd. U moet niet verder gaan met de betalingsactie van de order';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Waarschuwing!</strong> Hoewel u misschien credit card gegevens wilt invoeren voor een nieuwe of bestaande betaling zal geen online verwerking plaatsvinden.';
$lang['warning_order_paid_in_full'] = '<strong>Waarschuwing!</strong> Deze order lijkt al volledig betaald te zijn.';
$lang['weight'] = 'Gewicht';
$lang['within'] = 'Tussen';
$lang['yes'] = 'Ja';
$lang['utma'] = '156861353.1852221271.1287479092.1305060417.1305098379.144';
$lang['utmz'] = '156861353.1305060417.143.89.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['qca'] = 'P0-161031897-1287479092171';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
